==> 1.10.1.zip: entaxy-public/platform/integration/applications/application-impl/src/main/java/ru/entaxy/platform/integration/applications/impl/ApplicationObjectExtendedDataProvider.java <==
/*-
 * ~~~~~~licensing~~~~~~
 * application-impl
 * ==========
 * Copyright (C) 2020 - 2024 EmDev LLC
 * ==========
 * You may not use this file except in accordance with the License Terms of the Copyright
 * Holder located at: https://entaxy.ru/eula . All copyrights, all intellectual property
 * rights to the Software and any copies are the property of the Copyright Holder. Unless
 * it is explicitly allowed the Copyright Holder, the User is prohibited from using the
 * Software for commercial purposes to provide services to third parties.
 * 
 * The Copyright Holder hereby declares that the Software is provided on an "AS IS".
 * Under no circumstances does the Copyright Holder guarantee or promise that the
 * Software provided by him will be suitable or not suitable for the specific purposes
 * of the User, that the Software will meet all commercial and personal subjective
 * expectations of the User, that the Software will work properly, without technical
 * errors, quickly and uninterruptedly.
 * 
 * Under no circumstances shall the Copyright Holder or its Affiliates is not liable
 * to the User for any direct or indirect losses of the User, his expenses or actual
 * damage, including, downtime; loss of bussines; lost profit; lost earnings; loss
 * or damage to data, property, etc.
 * ~~~~~~/licensing~~~~~~
 */
package ru.entaxy.platform.integration.applications.impl;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.karaf.features.Feature;
import org.osgi.framework.Bundle;
import org.osgi.framework.BundleContext;
import org.osgi.service.component.ComponentContext;
import org.osgi.service.component.annotations.Activate;
import org.osgi.service.component.annotations.Component;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import ru.entaxy.platform.base.support.CommonUtils;
import ru.entaxy.platform.base.support.osgi.bundle.CapabilityDescriptor;
import ru.entaxy.platform.base.support.osgi.feature.FeatureCapabilityHelper;
import ru.entaxy.platform.base.support.osgi.feature.FeaturesUtils;
import ru.entaxy.platform.objects.runtime.EntaxyRuntimeObject;
import ru.entaxy.platform.objects.runtime.EntaxyRuntimeObjectExtendedDataProvider;

@Component(service = EntaxyRuntimeObjectExtendedDataProvider.class, immediate = true)
public class ApplicationObjectExtendedDataProvider implements EntaxyRuntimeObjectExtendedDataProvider {

    private static final Logger LOG = LoggerFactory.getLogger(ApplicationObjectExtendedDataProvider.class);

    private static final String APPLICATIONS_PROVIDER_ID = "applications";

    protected final static String APP_NAMESPACE = "entaxy.application";

    protected BundleContext bundleContext;

    @Activate
    public void activate(ComponentContext componentContext) {
        this.bundleContext = componentContext.getBundleContext();
    }

    @Override
    public String getProviderId() {
        return APPLICATIONS_PROVIDER_ID;
    }

    @Override
    public Map<String, Object> getExtendedData(EntaxyRuntimeObject runtimeObject) {
        Map<String, Object> result = new HashMap<>();
        try {
            Bundle b = bundleContext.getBundle(runtimeObject.getBundleInfo().getBundleId());
            List<Feature> features = FeaturesUtils.FeaturesHelper.create(bundleContext)
                    .withCapabilityNamespace(APP_NAMESPACE).containingBundle(b).find();
            if (features.isEmpty())
                return null;

            List<Map<String, Object>> applicationData = new ArrayList<>();
            for (Feature feature : features) {
                List<Map<String, Object>> featureApplications = getApplicationData(feature);
                if (!featureApplications.isEmpty())
                    applicationData.addAll(featureApplications);
            }

            if (applicationData.isEmpty())
                return null;

            result.put("application", applicationData);
            result.put("managed", true);

        } catch (Exception e) {
            result.put("error", String.format("[%s:%s]", e.getClass().getName(), e.getMessage()));
            LOG.error(String.format("Error getting extended data for [$s]", runtimeObject.getObjectFullId()), e);
        }
        return result;
    }

    protected List<Map<String, Object>> getApplicationData(Feature feature) {
        List<Map<String, Object>> result = new ArrayList<>();

        FeatureCapabilityHelper capabilityHelper = new FeatureCapabilityHelper(feature);
        List<CapabilityDescriptor> descriptors = capabilityHelper.getProvidedCapabilities(APP_NAMESPACE);
        for (CapabilityDescriptor descriptor : descriptors) {
            String name = descriptor.getAttributes().getOrDefault("name", "").toString();
            if (!CommonUtils.isValid(name))
                continue;
            String version = descriptor.getAttributes().getOrDefault("version", "").toString();
            String revision = descriptor.getAttributes().getOrDefault("revision", "").toString();

            Map<String, Object> data = new HashMap<>();
            data.put("name", name);
            data.put("version", version);
            data.put("revision", revision);
            result.add(data);
        }
        return result;
    }

}

==> 1.11.0.zip: entaxy-public/platform/integration/applications/application-impl/src/main/java/ru/entaxy/platform/integration/applications/impl/ApplicationObjectExtendedDataProvider.java <==
/*-
 * ~~~~~~licensing~~~~~~
 * application-impl
 * ==========
 * Copyright (C) 2020 - 2025 EmDev LLC
 * ==========
 * You may not use this file except in accordance with the License Terms of the Copyright
 * Holder located at: https://entaxy.ru/eula . All copyrights, all intellectual property
 * rights to the Software and any copies are the property of the Copyright Holder. Unless
 * it is explicitly allowed the Copyright Holder, the User is prohibited from using the
 * Software for commercial purposes to provide services to third parties.
 * 
 * The Copyright Holder hereby declares that the Software is provided on an "AS IS".
 * Under no circumstances does the Copyright Holder guarantee or promise that the
 * Software provided by him will be suitable or not suitable for the specific purposes
 * of the User, that the Software will meet all commercial and personal subjective
 * expectations of the User, that the Software will work properly, without technical
 * errors, quickly and uninterruptedly.
 * 
 * Under no circumstances shall the Copyright Holder or its Affiliates is not liable
 * to the User for any direct or indirect losses of the User, his expenses or actual
 * damage, including, downtime; loss of bussines; lost profit; lost earnings; loss
 * or damage to data, property, etc.
 * ~~~~~~/licensing~~~~~~
 */
package ru.entaxy.platform.integration.applications.impl;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.karaf.features.Feature;
import org.osgi.framework.Bundle;
import org.osgi.framework.BundleContext;
import org.osgi.service.component.ComponentContext;
import org.osgi.service.component.annotations.Activate;
import org.osgi.service.component.annotations.Component;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import ru.entaxy.platform.base.support.CommonUtils;
import ru.entaxy.platform.base.support.osgi.bundle.CapabilityDescriptor;
import ru.entaxy.platform.base.support.osgi.feature.FeatureCapabilityHelper;
import ru.entaxy.platform.base.support.osgi.feature.FeaturesUtils;
import ru.entaxy.platform.objects.runtime.EntaxyRuntimeObject;
import ru.entaxy.platform.objects.runtime.EntaxyRuntimeObjectExtendedDataProvider;

@Component(service = EntaxyRuntimeObjectExtendedDataProvider.class, immediate = true)
public class ApplicationObjectExtendedDataProvider implements EntaxyRuntimeObjectExtendedDataProvider {

    private static final Logger LOG = LoggerFactory.getLogger(ApplicationObjectExtendedDataProvider.class);

    private static final String APPLICATIONS_PROVIDER_ID = "applications";

    protected final static String APP_NAMESPACE = "entaxy.application";

    protected BundleContext bundleContext;

    @Activate
    public void activate(ComponentContext componentContext) {
        this.bundleContext = componentContext.getBundleContext();
    }

    @Override
    public String getProviderId() {
        return APPLICATIONS_PROVIDER_ID;
    }

    @Override
    public Map<String, Object> getExtendedData(EntaxyRuntimeObject runtimeObject) {
        Map<String, Object> result = new HashMap<>();
        try {
            Bundle b = bundleContext.getBundle(runtimeObject.getBundleInfo().getBundleId());
            List<Feature> features = FeaturesUtils.FeaturesHelper.create(bundleContext)
                    .withCapabilityNamespace(APP_NAMESPACE)
                    .installedOnly()
                    .containingBundle(b).find();
            if (features.isEmpty())
                return null;

            List<Map<String, Object>> applicationData = new ArrayList<>();
            for (Feature feature : features) {
                List<Map<String, Object>> featureApplications = getApplicationData(feature);
                if (!featureApplications.isEmpty())
                    applicationData.addAll(featureApplications);
            }

            if (applicationData.isEmpty())
                return null;

            result.put("application", applicationData);
            result.put("managed", true);

        } catch (Exception e) {
            result.put("error", String.format("[%s:%s]", e.getClass().getName(), e.getMessage()));
            LOG.error(String.format("Error getting extended data for [$s]", runtimeObject.getObjectFullId()), e);
        }
        return result;
    }

    protected List<Map<String, Object>> getApplicationData(Feature feature) {
        List<Map<String, Object>> result = new ArrayList<>();

        FeatureCapabilityHelper capabilityHelper = new FeatureCapabilityHelper(feature);
        List<CapabilityDescriptor> descriptors = capabilityHelper.getProvidedCapabilities(APP_NAMESPACE);
        for (CapabilityDescriptor descriptor : descriptors) {
            String name = descriptor.getAttributes().getOrDefault("name", "").toString();
            if (!CommonUtils.isValid(name))
                continue;
            String version = descriptor.getAttributes().getOrDefault("version", "").toString();
            String revision = descriptor.getAttributes().getOrDefault("revision", "").toString();

            Map<String, Object> data = new HashMap<>();
            data.put("name", name);
            data.put("version", version);
            data.put("revision", revision);
            result.add(data);
        }
        return result;
    }

}
